==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/WebKit/UIProcess/WebGrammarDetail.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebGrammarDetail_h
#define WebGrammarDetail_h

#include "APIObject.h"
#include <WebCore/TextCheckerClient.h>
#include <wtf/Forward.h>
#include <wtf/Ref.h>

namespace API {
class Array;
}

namespace WebKit {

class WebGrammarDetail : public API::ObjectImpl<API::Object::Type::GrammarDetail> {
public:
    static Ref<WebGrammarDetail> create(int location, int length, API::Array* guesses, const String& userDescription);
    static Ref<WebGrammarDetail> create(const WebCore::GrammarDetail&);

    int location() const { return m_grammarDetail.location; }
    int length() const { return m_grammarDetail.length; }
    Ref<API::Array> guesses() const;
    const String& userDescription() const { return m_grammarDetail.userDescription; }

    const WebCore::GrammarDetail& grammarDetail() { return m_grammarDetail; }

private:
    WebGrammarDetail(int location, int length, API::Array* guesses, const String& userDescription);
    explicit WebGrammarDetail(const WebCore::GrammarDetail&);

    WebCore::GrammarDetail m_grammarDetail;
};

} // namespace WebKit

#endif // WebGrammarDetail_h

==> webkit2gtk_2.34.6.orig.tar.xz: webkitgtk-2.34.6/Source/WebKit/UIProcess/WebGrammarDetail.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebGrammarDetail_h
#define WebGrammarDetail_h

#include "APIObject.h"
#include <WebCore/TextCheckerClient.h>
#include <wtf/Forward.h>
#include <wtf/Ref.h>

namespace API {
class Array;
}

namespace WebKit {

class WebGrammarDetail : public API::ObjectImpl<API::Object::Type::GrammarDetail> {
public:
    static Ref<WebGrammarDetail> create(int location, int length, API::Array* guesses, const String& userDescription);
    static Ref<WebGrammarDetail> create(const WebCore::GrammarDetail&);

    int location() const { return m_grammarDetail.range.location; }
    int length() const { return m_grammarDetail.range.length; }
    Ref<API::Array> guesses() const;
    const String& userDescription() const { return m_grammarDetail.userDescription; }

    const WebCore::GrammarDetail& grammarDetail() { return m_grammarDetail; }

private:
    WebGrammarDetail(int location, int length, API::Array* guesses, const String& userDescription);
    explicit WebGrammarDetail(const WebCore::GrammarDetail&);

    WebCore::GrammarDetail m_grammarDetail;
};

} // namespace WebKit

#endif // WebGrammarDetail_h
